package com.winhc.bigdata.spark.ng.utils

import com.winhc.bigdata.spark.ng.jobs.{args_company_job, general_handler}
import com.winhc.bigdata.spark.utils.{LoggingUtils, SparkUtils}
import org.apache.spark.sql.SparkSession

import scala.annotation.meta.getter
import scala.collection.mutable

/**
 * @author: XuJiakai
 * @date: 2021/4/29 10:53
 */
case class ReimportSummary(s: SparkSession
                           , tabs: Seq[String]
                          ) extends LoggingUtils {
  @(transient@getter) val spark: SparkSession = s


  private def re_explode(tn: String): Unit = {
    val ads_explode = s"winhc_ng.ads_${tn}_explode"
    val inc_ads_explode = s"winhc_ng.inc_ads_${tn}_explode"


    sql(s"ALTER TABLE $ads_explode DROP IF EXISTS PARTITION(ds>'0')")
    sql(s"ALTER TABLE $inc_ads_explode DROP IF EXISTS PARTITION(ds>'0')")

    general_handler(s = spark
      , project = "winhc_ng"
      , job_args = args_company_job.get_args_company_job(tn))
      .explode_calc()
  }

  def calc(): Unit = {
    for (e <- tabs) {
      re_explode(e)
    }
  }
}

object ReimportSummary {
  def main(args: Array[String]): Unit = {
    val project = "winhc_ng"
    val config = mutable.Map(
      "spark.hadoop.odps.project.name" -> project,
      "spark.debug.maxToStringFields" -> "200",
      "spark.hadoop.odps.spark.local.partition.amt" -> "100"
    )
    val spark = SparkUtils.InitEnv(this.getClass.getSimpleName + ":reimport", config)
    val tns = Seq("")
    ReimportSummary(spark, tns).calc()
    spark.stop()
  }
}
